@@ -1089,7 +1089,6 @@ static void
 override_fn (GtkObject *object, BonoboUINode *node, BonoboWinPrivate *priv)
 {
 	char     *id = node_get_id_or_path (node);
-	NodeInfo *info = bonobo_ui_xml_get_data (priv->tree, node);
 
 #ifdef XML_MERGE_DEBUG
 	fprintf (stderr, "Override '%s'\n", 
@@ -1098,9 +1097,6 @@ override_fn (GtkObject *object, BonoboUINode *node, BonoboWinPrivate *priv)
 
 	prune_widget_info (priv, node, TRUE);
 
-	real_emit_ui_event (priv, info->parent.id, id,
-			    Bonobo_UIComponent_OVERRIDDEN, "");
-
 	g_free (id);
 }
 
@@ -1108,7 +1104,6 @@ static void
 reinstate_fn (GtkObject *object, BonoboUINode *node, BonoboWinPrivate *priv)
 {
 	char     *id = node_get_id_or_path (node);
-	NodeInfo *info = bonobo_ui_xml_get_data (priv->tree, node);
 
 #ifdef XML_MERGE_DEBUG
 	fprintf (stderr, "Reinstate '%s'\n", 
@@ -1117,9 +1112,6 @@ reinstate_fn (GtkObject *object, BonoboUINode *node, BonoboWinPrivate *priv)
 
 	prune_widget_info (priv, node, TRUE);
 
-	real_emit_ui_event (priv, info->parent.id, id,
-			    Bonobo_UIComponent_REINSTATED, "");
-
 	g_free (id);
 }
 
@@ -1136,10 +1128,6 @@ static void
 remove_fn (GtkObject *object, BonoboUINode *node, BonoboWinPrivate *priv)
 {
 	char     *id = node_get_id_or_path (node);
-	NodeInfo *info = bonobo_ui_xml_get_data (priv->tree, node);
-
-	real_emit_ui_event (priv, info->parent.id, id,
-			    Bonobo_UIComponent_REMOVED, "");
 
 #ifdef XML_MERGE_DEBUG
 	fprintf (stderr, "Remove on '%s'\n",
@@ -1980,7 +1968,7 @@ toolbar_build_widget (BonoboWinPrivate *priv,
 		      NodeInfo         *info,
 		      GtkWidget        *parent)
 {
-	char         *type, *verb;
+	char         *type;
 	GtkWidget    *item;
 	BonoboUINode *cmd_node;
 
@@ -2014,16 +2002,6 @@ toolbar_build_widget (BonoboWinPrivate *priv,
 				  (*pos)++);
 	gtk_widget_show (item);
 
-	/* FIXME: What about "id"s ! ? */
-	if ((verb = bonobo_ui_node_get_attr (node, "verb"))) {
-		gtk_signal_connect (GTK_OBJECT (item), "activate",
-				    (GtkSignalFunc) exec_verb_cb, priv);
-		bonobo_ui_node_free_string (verb);
-	}
-
-	gtk_signal_connect (GTK_OBJECT (item), "state_altered",
-			    (GtkSignalFunc) win_item_emit_ui_event, priv);
-
 	return item;
 }
 
@@ -2035,12 +2013,25 @@ toolbar_build_item (BonoboWinPrivate *priv,
 		    GtkWidget        *parent)
 {
 	GtkWidget *widget;
+	char      *verb;
 	
 	if (bonobo_ui_node_has_name (node, "control"))
 		widget = toolbar_build_control (priv, node, pos, info, parent);
 	else
 		widget = toolbar_build_widget (priv, node, pos, info, parent);
 
+	if (widget) {
+		/* FIXME: What about "id"s ! ? */
+		if ((verb = bonobo_ui_node_get_attr (node, "verb"))) {
+			gtk_signal_connect (GTK_OBJECT (widget), "activate",
+					    (GtkSignalFunc) exec_verb_cb, priv);
+			bonobo_ui_node_free_string (verb);
+		}
+		
+		gtk_signal_connect (GTK_OBJECT (widget), "state_altered",
+				    (GtkSignalFunc) win_item_emit_ui_event, priv);
+	}
+
 	return widget;
 }
 
@@ -2063,6 +2054,22 @@ toolbar_build_placeholder (BonoboWinPrivate *priv,
 	return widget;
 }
 
+static BonoboUIToolbarControlDisplay
+decode_control_disp (const char *txt)
+{
+	if (!txt || !strcmp (txt, "control"))
+		return BONOBO_UI_TOOLBAR_CONTROL_DISPLAY_CONTROL;
+
+	else if (!strcmp (txt, "button"))
+		return BONOBO_UI_TOOLBAR_CONTROL_DISPLAY_BUTTON;
+
+	else if (!strcmp (txt, "none"))
+		return BONOBO_UI_TOOLBAR_CONTROL_DISPLAY_NONE;
+
+	else
+		return BONOBO_UI_TOOLBAR_CONTROL_DISPLAY_CONTROL;
+}
+
 static void
 toolbar_sync_state (BonoboWinPrivate *priv, BonoboUINode *node,
 		    GtkWidget *widget, GtkWidget *parent)
@@ -2102,7 +2109,6 @@ toolbar_sync_state (BonoboWinPrivate *priv, BonoboUINode *node,
 	bonobo_ui_node_free_string (sensitive);
 	bonobo_ui_node_free_string (hidden);
 
-	/* behaviors can apply to controls, so we need to handle them here */
 	if ((behavior = cmd_get_attr (node, cmd_node, "behavior"))) {
 		
 		behavior_array = g_strsplit (behavior, ",", -1);
@@ -2152,6 +2158,22 @@ toolbar_sync_state (BonoboWinPrivate *priv, BonoboUINode *node,
 	bonobo_ui_node_free_string (type);
 	bonobo_ui_node_free_string (label);
 
+	if (bonobo_ui_node_has_name (node, "control")) {
+		char *txt;
+		BonoboUIToolbarControlDisplay hdisp, vdisp;
+		
+		txt = bonobo_ui_node_get_attr (node, "hdisplay");
+		hdisp = decode_control_disp (txt);
+		bonobo_ui_node_free_string (txt);
+
+		txt = bonobo_ui_node_get_attr (node, "vdisplay");
+		vdisp = decode_control_disp (txt);
+		bonobo_ui_node_free_string (txt);
+
+		bonobo_ui_toolbar_control_item_set_display (
+			BONOBO_UI_TOOLBAR_CONTROL_ITEM (widget), hdisp, vdisp);
+	}
+
 	if ((min_width = cmd_get_attr (node, cmd_node, "min_width"))) {
 		bonobo_ui_toolbar_item_set_minimum_width (BONOBO_UI_TOOLBAR_ITEM (widget),
 							  atoi (min_width));
@@ -2179,6 +2201,15 @@ toolbar_sync_state (BonoboWinPrivate *priv, BonoboUINode *node,
 	}
 }
 
+static BonoboUIToolbarStyle
+parse_look (const char *look)
+{
+	if (!look || !strcmp (look, "both"))
+		return BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT;
+	else
+		return BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY;
+}
+
 static void
 update_dockitem (BonoboWinPrivate *priv, BonoboUINode *node)
 {
@@ -2188,6 +2219,7 @@ update_dockitem (BonoboWinPrivate *priv, BonoboUINode *node)
 	GnomeDockItem *item;
 	BonoboUIToolbar *toolbar;
 	GList *widgets, *wptr;
+	BonoboUIToolbarStyle look;
 	int    pos;
 
 	item = get_dock_item (priv, dockname);
@@ -2220,15 +2252,25 @@ update_dockitem (BonoboWinPrivate *priv, BonoboUINode *node)
 /*	bonobo_win_dump (priv->win, "after build widgets");*/
 
 	/* Update the attributes */
+
 	if ((txt = bonobo_ui_node_get_attr (node, "look"))) {
-		if (!strcmp (txt, "both"))
-			bonobo_ui_toolbar_set_style (
-				toolbar, BONOBO_UI_TOOLBAR_STYLE_ICONS_AND_TEXT);
-		else
-			bonobo_ui_toolbar_set_style (
-				toolbar, BONOBO_UI_TOOLBAR_STYLE_ICONS_ONLY);
+		look = parse_look (txt);
+		bonobo_ui_toolbar_set_hv_styles (toolbar, look, look);
 		bonobo_ui_node_free_string (txt);
-	}
+
+	} else {
+		BonoboUIToolbarStyle vlook, hlook;
+
+		txt = bonobo_ui_node_get_attr (node, "hlook");
+		hlook = parse_look (txt);
+		bonobo_ui_node_free_string (txt);
+
+		txt = bonobo_ui_node_get_attr (node, "vlook");
+		vlook = parse_look (txt);
+		bonobo_ui_node_free_string (txt);
+
+		bonobo_ui_toolbar_set_hv_styles (toolbar, hlook, vlook);
+	}		
 
 #if 0
 	if ((txt = bonobo_ui_node_get_attr (node, "relief"))) {
@@ -2784,11 +2826,21 @@ bonobo_win_set_contents (BonoboWin *win,
 GtkWidget *
 bonobo_win_get_contents (BonoboWin *win)
 {
+	GList     *children;
+	GtkWidget *widget;
+
 	g_return_val_if_fail (win != NULL, NULL);
 	g_return_val_if_fail (win->priv != NULL, NULL);
 	g_return_val_if_fail (win->priv->dock != NULL, NULL);
 
-	return GTK_BIN (win->priv->client_area)->child;
+	children = gtk_container_children (
+		GTK_CONTAINER (win->priv->client_area));
+
+	widget = children ? children->data : NULL;
+
+	g_list_free (children);
+
+	return widget;
 }
 
 static gboolean
