@@ -71,14 +71,22 @@ BonoboZoomable	*bonobo_zoomable_construct			(BonoboZoomable	*zoomable,
 								 Bonobo_Zoomable corba_zoomable);
 
 void		 bonobo_zoomable_set_parameters			(BonoboZoomable	*zoomable,
+								 float           zoom_level,
+								 float		 min_zoom_level,
+								 float		 max_zoom_level,
+								 gboolean	 has_min_zoom_level,
+								 gboolean	 has_max_zoom_level);
+
+void		 bonobo_zoomable_set_parameters_full		(BonoboZoomable	*zoomable,
 								 float           zoom_level,
 								 float		 min_zoom_level,
 								 float		 max_zoom_level,
 								 gboolean	 has_min_zoom_level,
 								 gboolean	 has_max_zoom_level,
 								 gboolean	 is_continuous,
-								 float		*preferred_zoom_levels,
-								 int		 num_preferred_zoom_levels);
+								 float          *preferred_zoom_levels,
+								 const gchar   **preferred_zoom_level_names,
+								 gint		 num_preferred_zoom_levels);
 
 void		 bonobo_zoomable_report_zoom_level_changed	(BonoboZoomable	*zoomable,
 								 float		 new_zoom_level);
